
# Type: local_names




URI: [meta:local_names](https://w3id.org/biolink/biolinkml/meta/local_names)


## Domain and Range

[Element](Element.md) ->  <sub>0..*</sub> [LocalName](LocalName.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
